@@ -187,7 +187,7 @@ class MaxTaskCapacityOption(Range):
     display_name = "Max Task Capacity"
     range_start = 1
     range_end = 6
-    default = 4
+    default = 6
 
 
 class WinConditions(OptionList):
@@ -225,6 +225,30 @@ class WinConditions(OptionList):
     visibility = ~(Visibility.simple_ui|Visibility.complex_ui)
 
 
+class OmitRandomWinConditions(OptionList):
+    """
+    Allows for the selected win conditions to be omitted when randomizing a win condition.
+    Example: Adding "bounties" to this option will ensure bounties can't be rolled when you roll for a randomized win condition
+
+    valid keys: ["cog-bosses", "bounties", "total-tasks", "hood-tasks", "gag-tracks",
+                 "fish-species", "laff-o-lympics"]
+
+    Examples: ["cog-bosses", "hood-tasks"] | ["randomized", "randomized", "gag-tracks"]
+    """
+    display_name = "Win Conditions Omitted when Randomized"
+    valid_keys = {
+        "cog-bosses",
+        "total-tasks",
+        "hood-tasks",
+        "gag-tracks",
+        "fish-species",
+        "laff-o-lympics",
+        "bounties"
+    }
+    default = []
+    visibility = ~(Visibility.simple_ui|Visibility.complex_ui)
+
+
 class WinConditionCogBossesWeb(Toggle):
     """Defeat a number of cog bosses to complete the game (determined by cog_bosses_required)."""
     display_name = "Cog Bosses"
@@ -240,7 +264,7 @@ class CogBossesRequired(Range):
     display_name = "Bosses Required"
     range_start = 0
     range_end = 4
-    default = 4
+    default = 3
 
 
 class WinConditionTotalTasksWeb(Toggle):
@@ -316,7 +340,7 @@ class FishSpeciesRequired(Range):
     display_name = "Fish Required"
     range_start = 0
     range_end = 70
-    default = 70
+    default = 60
 
 
 class WinConditionLaffOLympicsWeb(Toggle):
@@ -354,7 +378,7 @@ class BountiesRequired(Range):
     display_name = "Bounties Required"
     range_start = 0
     range_end = 33
-    default = 10
+    default = 7
 
 
 class TotalBounties(Range):
@@ -367,7 +391,7 @@ class TotalBounties(Range):
     display_name = "Total Bounties"
     range_start = 1
     range_end = 33
-    default = 20
+    default = 15
 
 
 class BountiesHinted(Toggle):
@@ -523,7 +547,7 @@ class MaxedCogGalleryQuota(Range):
     display_name = "Maxed Cog Gallery Quota"
     range_start = 1
     range_end = 10
-    default = 3
+    default = 2
 
 
 class FacilityLocking(Choice):
@@ -586,6 +610,16 @@ class FishProgression(Choice):
     default = 2
 
 
+class FishPity(Range):
+    """
+    The amount of pity (% chance of a guarantee) gained towards a new species per catch.
+    """
+    display_name = "Fishing Pity Per Catch"
+    range_start = 0
+    range_end = 100
+    default = 25
+
+
 class RacingOption(Toggle):
     """
     Enable to turn on racing checks.
@@ -823,6 +857,17 @@ class HealWeightOption(Range):
     display_name = "Healing Junk Weight"
     range_start = 0
     range_end = 100
+    default = 75
+
+
+class FishWeightOption(Range):
+    """
+    Weight of Fish items in the junk pool.
+    """
+
+    display_name = "Fish Junk Weight"
+    range_start = 0
+    range_end = 100
     default = 65
 
 
@@ -869,6 +914,7 @@ class ToontownOptions(PerGameCommonOptions):
     starting_task_capacity: StartingTaskCapacityOption
     max_task_capacity: MaxTaskCapacityOption
     win_condition: WinConditions
+    conditions_omitted_when_randomized: OmitRandomWinConditions
     web_win_condition_cog_bosses: WinConditionCogBossesWeb
     web_win_condition_total_tasks: WinConditionTotalTasksWeb
     web_win_condition_hood_tasks: WinConditionHoodTasksWeb
@@ -901,6 +947,7 @@ class ToontownOptions(PerGameCommonOptions):
     fish_locations: FishLocations
     fish_checks: FishChecks
     fish_progression: FishProgression
+    fish_pity: FishPity
     slot_sync_jellybeans: SyncJellybeans
     slot_sync_gag_experience: SyncGagExp
     racing_logic: RacingOption
@@ -918,6 +965,7 @@ class ToontownOptions(PerGameCommonOptions):
     unite_weight: UniteWeightOption
     fire_weight: FireWeightOption
     heal_weight: HealWeightOption
+    fish_weight: FishWeightOption
     death_link: DeathLinkOption
     ring_link: RingLinkOption
     pet_shop_display: PetShopRewardDisplayOption
@@ -939,7 +987,7 @@ toontown_option_groups: list[OptionGroup] = [
         RingLinkOption, RandomShopCostToggle
     ]),
     OptionGroup("Win Condition", [
-        WinConditions, WinConditionRandomizedWeb,
+        WinConditions, WinConditionRandomizedWeb, OmitRandomWinConditions,
         WinConditionCogBossesWeb, CogBossesRequired,
         WinConditionTotalTasksWeb, TotalTasksRequired,
         WinConditionHoodTasksWeb, HoodTasksRequired,
@@ -952,11 +1000,11 @@ toontown_option_groups: list[OptionGroup] = [
         TPSanity, TreasuresPerLocation, ChecksPerBoss, GagTrainingCheckBehavior,
         GagTrainingFrameBehavior, LogicalTasksPerPlayground, LogicalMaxedCogGallery,
         MaxedCogGalleryQuota, FacilityLocking, FishChecks, FishLocations,
-        FishProgression, RacingOption, GolfingOption, SeedGenerationTypeOption,
+        FishProgression, FishPity, RacingOption, GolfingOption, SeedGenerationTypeOption,
         JokesPerStreet, JokeBookToggle
     ], False),
     OptionGroup("Junk Weights", [
-        BeanWeightOption, GagExpWeightOption, SOSWeightOption, UniteWeightOption, FireWeightOption, HealWeightOption
+        BeanWeightOption, GagExpWeightOption, SOSWeightOption, UniteWeightOption, FireWeightOption, HealWeightOption, FishWeightOption
     ], True),
     OptionGroup("Trap Weights", [
         UberWeightOption, DripWeightOption, TaxWeightOption, ShuffleWeightOption, DamageWeightOption
